.. _api_charset:

Character Encoding and Decoding (:mod:`pydicom.charset`)
========================================================

.. currentmodule:: pydicom.charset

Character encoding and decoding functions.

.. autosummary::
   :toctree: generated/

   convert_encodings
   decode_element
   decode_bytes
   encode_string
